@@ -406,7 +406,7 @@ camel_ews_folder_get_message (CamelFolder *folder,
 	ews_folder = (CamelEwsFolder *) folder;
 	priv = ews_folder->priv;
 
-	if (!camel_ews_store_connected (ews_store, error))
+	if (!camel_ews_store_connected (ews_store, cancellable, error))
 		return NULL;
 
 	g_mutex_lock (priv->state_lock);
@@ -819,7 +819,7 @@ ews_sync_mi_flags (CamelFolder *folder,
 
 	ews_store = (CamelEwsStore *) camel_folder_get_parent_store (folder);
 
-	if (!camel_ews_store_connected (ews_store, error)) {
+	if (!camel_ews_store_connected (ews_store, cancellable, error)) {
 		return FALSE;
 	}
 
@@ -891,7 +891,7 @@ ews_move_to_junk_folder (CamelFolder *folder,
 	ews_folder = CAMEL_EWS_FOLDER (folder);
 	ews_store = CAMEL_EWS_STORE (parent_store);
 
-	if (!camel_ews_store_connected (ews_store, error))
+	if (!camel_ews_store_connected (ews_store, cancellable, error))
 		return FALSE;
 
 	cnc = camel_ews_store_ref_connection (ews_store);
@@ -972,7 +972,7 @@ ews_synchronize_sync (CamelFolder *folder,
 
 	ews_store = (CamelEwsStore *) camel_folder_get_parent_store (folder);
 
-	if (!camel_ews_store_connected (ews_store, error))
+	if (!camel_ews_store_connected (ews_store, cancellable, error))
 		return FALSE;
 
 	if (camel_folder_summary_get_deleted_count (folder->summary) > 0 ||
@@ -1392,7 +1392,7 @@ ews_refresh_info_sync (CamelFolder *folder,
 	ews_folder = (CamelEwsFolder *) folder;
 	priv = ews_folder->priv;
 
-	if (!camel_ews_store_connected (ews_store, error))
+	if (!camel_ews_store_connected (ews_store, cancellable, error))
 		return FALSE;
 
 	g_mutex_lock (priv->state_lock);
@@ -1499,6 +1499,7 @@ ews_append_message_sync (CamelFolder *folder,
 	gchar *itemid, *changekey;
 	const gchar *folder_name;
 	gchar *folder_id;
+	EwsFolderId *fid;
 	CamelAddress *from;
 	CamelEwsStore *ews_store;
 	EEwsConnection *cnc;
@@ -1506,6 +1507,10 @@ ews_append_message_sync (CamelFolder *folder,
 
 	ews_store = (CamelEwsStore *) camel_folder_get_parent_store (folder);
 
+	if (!camel_ews_store_connected (ews_store, cancellable, error)) {
+		return FALSE;
+	}
+
 	folder_name = camel_folder_get_full_name (folder);
 	folder_id = camel_ews_store_summary_get_folder_id_from_name (
 		ews_store->summary,
@@ -1515,30 +1520,30 @@ ews_append_message_sync (CamelFolder *folder,
 
 	from = CAMEL_ADDRESS (camel_mime_message_get_from (message));
 
-	if (!camel_ews_store_connected (ews_store, error)) {
-		return FALSE;
-	}
-
 	cnc = camel_ews_store_ref_connection (ews_store);
 
 	if (!cnc) {
+		g_free (folder_id);
 		g_set_error (
 			error, CAMEL_ERROR, CAMEL_ERROR_GENERIC,
 			_("Cant perform actions on the folder while in offline mode"));
 		return FALSE;
 	}
 
+	fid = e_ews_folder_id_new (folder_id, NULL, FALSE);
 	if (!camel_ews_utils_create_mime_message (
-		cnc, "SaveOnly", folder_id, message,
+		cnc, "SaveOnly", fid, message,
 		camel_message_info_flags (info),
 		from, &itemid, &changekey,
 		cancellable, &local_error)) {
 		camel_ews_store_maybe_disconnect (ews_store, local_error);
 		g_propagate_error (error, local_error);
+		e_ews_folder_id_free (fid);
 		g_free (folder_id);
 		g_object_unref (cnc);
 		return FALSE;
 	}
+	e_ews_folder_id_free (fid);
 	g_free (folder_id);
 
 	/* FIXME: Do we have to add it to the summary info ourselves?
@@ -1576,7 +1581,7 @@ ews_transfer_messages_to_sync (CamelFolder *source,
 	dst_full_name = camel_folder_get_full_name (destination);
 	dst_ews_store = (CamelEwsStore *) camel_folder_get_parent_store (destination);
 
-	if (!camel_ews_store_connected (dst_ews_store, error))
+	if (!camel_ews_store_connected (dst_ews_store, cancellable, error))
 		return FALSE;
 
 	cnc = camel_ews_store_ref_connection (dst_ews_store);
@@ -1644,7 +1649,7 @@ ews_delete_messages (CamelFolder *folder,
 	ews_store = CAMEL_EWS_STORE (parent_store);
 	deleted_head = deleted_items;
 
-	if (!camel_ews_store_connected (ews_store, error)) {
+	if (!camel_ews_store_connected (ews_store, cancellable, error)) {
 		return FALSE;
 	}
 
@@ -1718,7 +1723,7 @@ ews_expunge_sync (CamelFolder *folder,
 	parent_store = camel_folder_get_parent_store (folder);
 	ews_store = CAMEL_EWS_STORE (parent_store);
 
-	if (!camel_ews_store_connected (ews_store, error))
+	if (!camel_ews_store_connected (ews_store, cancellable, error))
 		return FALSE;
 
 	is_trash = ews_folder_is_of_type (folder, CAMEL_FOLDER_TYPE_TRASH);
