@@ -10,6 +10,7 @@
 #define S_UNLOCK(x) (g_static_rec_mutex_unlock(&(x)->priv->s_lock))
 
 #define STORE_GROUP_NAME "##storepriv"
+#define CURRENT_SUMMARY_VERSION 1
 
 struct _CamelEwsStoreSummaryPrivate {
 	GKeyFile *key_file;
@@ -104,6 +105,9 @@ load_id_fname_hash (CamelEwsStoreSummary *ews_summary)
 {
 	GSList *folders, *l;
 
+	g_hash_table_remove_all (ews_summary->priv->fname_id_hash);
+	g_hash_table_remove_all (ews_summary->priv->id_fname_hash);
+
 	folders = camel_ews_store_summary_get_folders (ews_summary, NULL);
 
 	for (l = folders; l != NULL; l = g_slist_next (l)) {
@@ -156,13 +160,20 @@ camel_ews_store_summary_new (const gchar *path)
 
 	ews_summary->priv->path = g_strdup (path);
 	file = g_file_new_for_path (path);
-	ews_summary->priv->monitor_delete = g_file_monitor_file (file, G_FILE_MONITOR_SEND_MOVED, NULL, &error);
+	ews_summary->priv->monitor_delete = g_file_monitor_file (
+		file, G_FILE_MONITOR_SEND_MOVED, NULL, &error);
 
-	/* Remove this once we have camel_store_remove_storage api, which should be available from 3.2 */
-	if (!error)
-		g_signal_connect (ews_summary->priv->monitor_delete, "changed", G_CALLBACK (monitor_delete_cb), ews_summary);
-	else {
-		g_warning ("CamelEwsStoreSummary: Error create monitor_delete: %s \n", error->message);
+	/* Remove this once we have camel_store_remove_storage api,
+	 * which should be available from 3.2 */
+	if (!error) {
+		g_signal_connect (
+			ews_summary->priv->monitor_delete, "changed",
+			G_CALLBACK (monitor_delete_cb), ews_summary);
+	} else {
+		g_warning (
+			"CamelEwsStoreSummary: "
+			"Error create monitor_delete: %s \n",
+			error->message);
 		g_clear_error (&error);
 	}
 
@@ -177,13 +188,27 @@ camel_ews_store_summary_load (CamelEwsStoreSummary *ews_summary,
 {
 	CamelEwsStoreSummaryPrivate *priv = ews_summary->priv;
 	gboolean ret;
+	gint version;
 
 	S_LOCK (ews_summary);
 
 	ret = g_key_file_load_from_file (
 		priv->key_file, priv->path, 0, error);
 
+	version = g_key_file_get_integer (
+		priv->key_file, STORE_GROUP_NAME, "Version", NULL);
+
+	if (version != CURRENT_SUMMARY_VERSION) {
+		/* version doesn't match, get folders again */
+		camel_ews_store_summary_clear (ews_summary);
+
+		g_key_file_set_integer (
+			priv->key_file, STORE_GROUP_NAME,
+			"Version", CURRENT_SUMMARY_VERSION);
+	}
+
 	load_id_fname_hash (ews_summary);
+
 	S_UNLOCK (ews_summary);
 
 	return ret;
@@ -252,6 +277,16 @@ camel_ews_store_summary_remove (CamelEwsStoreSummary *ews_summary)
 	return (ret == 0);
 }
 
+void
+camel_ews_store_summary_rebuild_hashes (CamelEwsStoreSummary *ews_summary)
+{
+	g_return_if_fail (CAMEL_IS_EWS_STORE_SUMMARY (ews_summary));
+
+	S_LOCK (ews_summary);
+	load_id_fname_hash (ews_summary);
+	S_UNLOCK (ews_summary);
+}
+
 struct subfolder_match {
 	GSList *ids;
 	gchar *match;
@@ -346,7 +381,8 @@ camel_ews_store_summary_new_folder (CamelEwsStoreSummary *ews_summary,
                                     const gchar *display_name,
                                     EEwsFolderType folder_type,
                                     guint64 folder_flags,
-                                    guint64 total)
+                                    guint64 total,
+                                    gboolean foreign)
 {
 	const gchar *folder_type_nick;
 
@@ -356,12 +392,14 @@ camel_ews_store_summary_new_folder (CamelEwsStoreSummary *ews_summary,
 
 	S_LOCK (ews_summary);
 
-	g_key_file_set_string (
-		ews_summary->priv->key_file,
-		folder_id, "ParentFolderId", parent_fid);
-	g_key_file_set_string (
-		ews_summary->priv->key_file,
-		folder_id, "ChangeKey", change_key);
+	if (parent_fid)
+		g_key_file_set_string (
+			ews_summary->priv->key_file,
+			folder_id, "ParentFolderId", parent_fid);
+	if (change_key)
+		g_key_file_set_string (
+			ews_summary->priv->key_file,
+			folder_id, "ChangeKey", change_key);
 	g_key_file_set_string (
 		ews_summary->priv->key_file,
 		folder_id, "DisplayName", display_name);
@@ -374,6 +412,9 @@ camel_ews_store_summary_new_folder (CamelEwsStoreSummary *ews_summary,
 	g_key_file_set_uint64 (
 		ews_summary->priv->key_file,
 		folder_id, "Total", total);
+	g_key_file_set_boolean (
+		ews_summary->priv->key_file,
+		folder_id, "Foreign", foreign);
 
 	ews_ss_hash_replace (ews_summary, g_strdup (folder_id), NULL, FALSE);
 
@@ -501,6 +542,21 @@ camel_ews_store_summary_set_folder_type (CamelEwsStoreSummary *ews_summary,
 	S_UNLOCK (ews_summary);
 }
 
+void
+camel_ews_store_summary_set_foreign (CamelEwsStoreSummary *ews_summary,
+                                     const gchar *folder_id,
+                                     gboolean is_foreign)
+{
+	S_LOCK (ews_summary);
+
+	g_key_file_set_boolean (
+		ews_summary->priv->key_file,
+		folder_id, "Foreign", is_foreign);
+	ews_summary->priv->dirty = TRUE;
+
+	S_UNLOCK (ews_summary);
+}
+
 void
 camel_ews_store_summary_store_string_val (CamelEwsStoreSummary *ews_summary,
                                           const gchar *key,
@@ -688,6 +744,23 @@ camel_ews_store_summary_get_folder_type (CamelEwsStoreSummary *ews_summary,
 	return folder_type;
 }
 
+gboolean
+camel_ews_store_summary_get_foreign (CamelEwsStoreSummary *ews_summary,
+                                     const gchar *folder_id,
+                                     GError **error)
+{
+	gboolean ret;
+
+	S_LOCK (ews_summary);
+
+	ret = g_key_file_get_boolean (
+		ews_summary->priv->key_file, folder_id, "Foreign", error);
+
+	S_UNLOCK (ews_summary);
+
+	return ret;
+}
+
 gchar *
 camel_ews_store_summary_get_string_val (CamelEwsStoreSummary *ews_summary,
                                          const gchar *key,
@@ -729,7 +802,10 @@ camel_ews_store_summary_get_folders (CamelEwsStoreSummary *ews_summary,
 		if (!g_ascii_strcasecmp (groups[i], STORE_GROUP_NAME))
 			continue;
 		if (prefixlen) {
-			const gchar *fname = g_hash_table_lookup (ews_summary->priv->id_fname_hash, groups[i]);
+			const gchar *fname;
+
+			fname = g_hash_table_lookup (
+				ews_summary->priv->id_fname_hash, groups[i]);
 
 			if (!fname || strncmp (fname, prefix, prefixlen) ||
 			    (fname[prefixlen] && fname[prefixlen] != '/'))
@@ -810,7 +886,8 @@ camel_ews_store_summary_get_folder_id_from_folder_type (CamelEwsStoreSummary *ew
 		gchar *id = l->data;
 		guint64 folder_flags;
 
-		folder_flags = camel_ews_store_summary_get_folder_flags (ews_summary, id, NULL);
+		folder_flags = camel_ews_store_summary_get_folder_flags (
+			ews_summary, id, NULL);
 		if ((folder_flags & CAMEL_FOLDER_TYPE_MASK) == folder_type &&
 		    (folder_flags & CAMEL_FOLDER_SYSTEM) != 0) {
 			folder_id = id;
