@@ -48,14 +48,21 @@ con_test_create_new_connection ()
 	const gchar *password;
 	const gchar *uri;
 	EEwsConnection *cnc;
+	CamelEwsSettings *settings;
 
 	util_get_login_info_from_env (&username, &password, &uri);
 	g_assert_cmpstr (username, !=, NULL);
 	g_assert_cmpstr (password, !=, NULL);
 	g_assert_cmpstr (uri, !=, NULL);
 
-	cnc = e_ews_connection_new (uri, username, password, NULL, 30, NULL, NULL, NULL);
-	g_assert (cnc != NULL);
+	settings = g_object_new (
+		CAMEL_TYPE_EWS_SETTINGS,
+		"user", username, NULL);
+
+	cnc = e_ews_connection_new (uri, settings);
+	e_ews_connection_set_password (cnc, password);
+
+	g_object_unref (settings);
 
 	g_print ("\nSuccess : Created a new connection\n");
 
@@ -118,8 +125,8 @@ con_test_autodiscover ()
 
 	util_get_email_from_env (&email);
 	g_assert_cmpstr (email, !=, NULL);
-	g_print("%s %s : password : %s \n", G_STRLOC, G_STRFUNC, password);
-	g_print("%s %s : email : %s \n", G_STRLOC, G_STRFUNC, email);
+	g_print ("%s %s : password : %s \n", G_STRLOC, G_STRFUNC, password);
+	g_print ("%s %s : email : %s \n", G_STRLOC, G_STRFUNC, email);
 
 	user_data = g_new0 (struct _cb_data, 1);
 	user_data->test_case = g_strdup ("postive case... \n");
