@@ -48,8 +48,7 @@ create_folder_cb (GObject *object,
 	GError *error = NULL;
 	EwsFolderId *fid = NULL;
 
-	e_ews_connection_create_folder_finish	(cnc, res, &fid,
-						 &error);
+	e_ews_connection_create_folder_finish (cnc, res, &fid, &error);
 	if (error != NULL) {
 		g_warning ("Unable to create: %s \n", error->message);
 		g_clear_error (&error);
@@ -63,7 +62,7 @@ create_folder_cb (GObject *object,
 	folder_id->id = g_strdup (fid->id);
 	folder_id->change_key = g_strdup (fid->change_key);
 
-	e_ews_folder_free_fid (fid);
+	e_ews_folder_id_free (fid);
 
 quit:
 	g_main_loop_quit (main_loop);
@@ -77,6 +76,7 @@ op_test_create_folder ()
 	const gchar *uri;
 	EEwsConnection *cnc;
 	GCancellable *cancellable;
+	CamelEwsSettings *settings;
 
 	cancellable = g_cancellable_new ();
 
@@ -85,8 +85,15 @@ op_test_create_folder ()
 	g_assert_cmpstr (password, !=, NULL);
 	g_assert_cmpstr (uri, !=, NULL);
 
-	cnc = e_ews_connection_new (uri, username, password, NULL, 30, NULL, NULL, NULL);
-	g_assert (cnc != NULL);
+	settings = g_object_new (
+		CAMEL_TYPE_EWS_SETTINGS,
+		"user", username, NULL);
+
+	cnc = e_ews_connection_new (uri, settings);
+	e_ews_connection_set_password (cnc, password);
+
+	g_object_unref (settings);
+
 	e_ews_connection_create_folder (
 		cnc, EWS_PRIORITY_MEDIUM, "inbox",
 		TRUE ,"test", cancellable,
